@@ -2,12 +2,14 @@ require 'active_model/serializable/utils'
 
 module ActiveModel
   module Serializable
+    INSTRUMENTATION_KEY = '!serialize.active_model_serializers'.freeze
+
     def self.included(base)
       base.extend Utils
     end
 
     def as_json(options={})
-      instrument('!serialize') do
+      instrument do
         if root = options.fetch(:root, json_key)
           hash = { root => serializable_object(options) }
           hash.merge!(serializable_data)
@@ -19,9 +21,7 @@ module ActiveModel
     end
 
     def serializable_object_with_notification(options={})
-      instrument('!serialize') do
-        serializable_object(options)
-      end
+      instrument { serializable_object(options) }
     end
 
     def serializable_data
@@ -33,7 +33,11 @@ module ActiveModel
     end
 
     def namespace
-      get_namespace && Utils._const_get(get_namespace)
+      if module_name = get_namespace
+        Serializer.serializers_cache.fetch_or_store(module_name) do
+          Utils._const_get(module_name)
+        end
+      end
     end
 
     def embedded_in_root_associations
@@ -47,16 +51,9 @@ module ActiveModel
       modules[0..-2].join('::') if modules.size > 1
     end
 
-    def instrument(action, &block)
-      payload = instrumentation_keys.inject({ serializer: self.class.name }) do |payload, key|
-        payload[:payload] = self.instance_variable_get(:"@#{key}")
-        payload
-      end
-      ActiveSupport::Notifications.instrument("#{action}.active_model_serializers", payload, &block)
-    end
-
-    def instrumentation_keys
-      [:object, :scope, :root, :meta_key, :meta, :wrap_in_array, :only, :except, :key_format]
+    def instrument(&block)
+      payload = { serializer: self.class.name }
+      ActiveSupport::Notifications.instrument(INSTRUMENTATION_KEY, payload, &block)
     end
   end
 end
